extern const guint8 icon_article_new[]; 
extern const guint8 icon_article_read[]; 
extern const guint8 icon_article_unread[]; 
extern const guint8 icon_compose_followup[]; 
extern const guint8 icon_compose_post[]; 
extern const guint8 icon_compose_send[]; 
extern const guint8 icon_binary_complete[]; 
extern const guint8 icon_binary_incomplete[]; 
extern const guint8 icon_binary[]; 
extern const guint8 icon_bluecheck[]; 
extern const guint8 icon_blue_flag[]; 
extern const guint8 icon_bozo[]; 
extern const guint8 icon_by_me[]; 
extern const guint8 icon_by_others[]; 
extern const guint8 icon_cancel[]; 
extern const guint8 icon_caution[]; 
extern const guint8 icon_disk[]; 
extern const guint8 icon_filter[]; 
extern const guint8 icon_filter_only_attachments[]; 
extern const guint8 icon_filter_only_cached[]; 
extern const guint8 icon_filter_only_me[]; 
extern const guint8 icon_filter_only_new[]; 
extern const guint8 icon_filter_only_score[]; 
extern const guint8 icon_filter_only_watched[]; 
extern const guint8 icon_folder[]; 
extern const guint8 icon_get_flagged[]; 
extern const guint8 icon_get_new[]; 
extern const guint8 icon_get_selected[]; 
extern const guint8 icon_get_subscribed[]; 
extern const guint8 icon_inform[]; 
extern const guint8 icon_layout_1[]; 
extern const guint8 icon_layout_2[]; 
extern const guint8 icon_layout_3[]; 
extern const guint8 icon_layout_4[]; 
extern const guint8 icon_layout_5[]; 
extern const guint8 icon_layout_6[]; 
extern const guint8 icon_newsgroup[]; 
extern const guint8 icon_online[]; 
extern const guint8 icon_offline[]; 
extern const guint8 icon_pan_druid[]; 
extern const guint8 icon_pan[]; 
extern const guint8 icon_read_group[]; 
extern const guint8 icon_read_more[]; 
extern const guint8 icon_read_less[]; 
extern const guint8 icon_read_new_article[]; 
extern const guint8 icon_read_new_thread[]; 
extern const guint8 icon_score[]; 
extern const guint8 icon_server[]; 
extern const guint8 icon_stock_mail_forward[]; 
extern const guint8 icon_stock_mail_receive[]; 
extern const guint8 icon_stock_mail_reply[]; 
extern const guint8 icon_stock_menu_about[]; 
extern const guint8 icon_stock_timer[]; 
extern const guint8 icon_watched[]; 
extern const guint8 icon_x[]; 
